@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -54,10 +54,10 @@ import org.osgi.framework.BundleActivator;
 import org.osgi.framework.BundleContext;
 import org.osgi.framework.Constants;
 import org.osgi.framework.ServiceRegistration;
+import com.openexchange.database.provider.DBProvider;
 import com.openexchange.datatypes.genericonf.storage.GenericConfigurationStorageService;
 import com.openexchange.exceptions.osgi.ComponentRegistration;
 import com.openexchange.groupware.delete.DeleteListener;
-import com.openexchange.groupware.tx.DBProvider;
 import com.openexchange.publish.PublicationErrorMessage;
 import com.openexchange.publish.PublicationTargetDiscoveryService;
 import com.openexchange.publish.database.PublicationUserDeleteListener;
@@ -95,14 +95,12 @@ public class DiscovererActivator implements BundleActivator {
 
         discovererCollector.ignore(compositeDiscovererCollector);
 
-        final Hashtable<Object, Object> discoveryDict = new Hashtable<Object, Object>();
+        final Hashtable<String, Object> discoveryDict = new Hashtable<String, Object>(1);
         discoveryDict.put(Constants.SERVICE_RANKING, Integer.valueOf(256));
 
         discoveryRegistration =
             context.registerService(PublicationTargetDiscoveryService.class.getName(), compositeDiscovererCollector, discoveryDict);
 
-        FolderFieldActivator.setDiscoverer( compositeDiscovererCollector );
-
         final DBProvider provider = whiteboard.getService(DBProvider.class);
         final GenericConfigurationStorageService confStorage = whiteboard.getService(GenericConfigurationStorageService.class);
 
@@ -111,7 +109,7 @@ public class DiscovererActivator implements BundleActivator {
 
         componentRegistration = new ComponentRegistration(context, "PUB", "com.openexchange.publish", PublicationErrorMessage.EXCEPTIONS);
         
-        PublicationUserDeleteListener listener = new PublicationUserDeleteListener();
+        final PublicationUserDeleteListener listener = new PublicationUserDeleteListener();
         listener.setDiscoveryService(compositeDiscovererCollector);
         listener.setGenConfStorage(confStorage);
         
