@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -60,9 +60,11 @@ import com.openexchange.api2.ContactSQLInterface;
 import com.openexchange.api2.OXConcurrentModificationException;
 import com.openexchange.api2.OXException;
 import com.openexchange.contact.LdapServer;
+import com.openexchange.groupware.contact.ContactUnificationState;
 import com.openexchange.groupware.container.Contact;
 import com.openexchange.groupware.search.ContactSearchObject;
 import com.openexchange.groupware.search.Order;
+import com.openexchange.search.SearchTerm;
 import com.openexchange.session.Session;
 import com.openexchange.tools.iterator.SearchIterator;
 import com.openexchange.tools.iterator.SearchIteratorAdapter;
@@ -114,12 +116,12 @@ public class SimContactSQLInterface implements ContactSQLInterface {
      * com.openexchange.groupware.contact.ContactInterface#getContactsByExtendedSearch(com.openexchange.groupware.search.ContactSearchObject
      * , int, java.lang.String, int[])
      */
-    public SearchIterator<Contact> getContactsByExtendedSearch(final ContactSearchObject searchobject, final int orderBy, final Order order, final int[] cols) throws OXException {
+    public SearchIterator<Contact> getContactsByExtendedSearch(final ContactSearchObject searchobject, final int orderBy, final Order order, final String collation, final int[] cols) throws OXException {
         // TODO Auto-generated method stub
         return null;
     }
 
-    public SearchIterator<Contact> getContactsInFolder(final int folderId, final int from, final int to, final int orderBy, final Order order, final int[] cols) throws OXException {
+    public SearchIterator<Contact> getContactsInFolder(final int folderId, final int from, final int to, final int orderBy, final Order order, final String collation, final int[] cols) throws OXException {
         return new SearchIteratorAdapter(getFolderList(folderId).iterator());
     }
 
@@ -190,6 +192,11 @@ public class SimContactSQLInterface implements ContactSQLInterface {
         return null;
     }
 
+    public Contact[] getUsersById(int[] userIds, boolean performReadCheck) throws OXException {
+        // TODO Auto-generated method stub
+        return null;
+    }
+
     /*
      * (non-Javadoc)
      * @see com.openexchange.groupware.contact.ContactInterface#getUserById(int)
@@ -246,4 +253,57 @@ public class SimContactSQLInterface implements ContactSQLInterface {
         return folders.get(folderId);
     }
 
+    /* (non-Javadoc)
+     * @see com.openexchange.groupware.contact.ContactInterface#associateTwoContacts(com.openexchange.groupware.container.Contact, com.openexchange.groupware.container.Contact)
+     */
+    public void associateTwoContacts(Contact master, Contact slave) throws OXException {
+        // TODO Auto-generated method stub
+        
+    }
+
+    /* (non-Javadoc)
+     * @see com.openexchange.groupware.contact.ContactInterface#getAssociatedContacts(com.openexchange.groupware.container.Contact)
+     */
+    public List<Contact> getAssociatedContacts(Contact contact) throws OXException {
+        // TODO Auto-generated method stub
+        return null;
+    }
+
+    /* (non-Javadoc)
+     * @see com.openexchange.groupware.contact.ContactInterface#getAssociationBetween(com.openexchange.groupware.container.Contact, com.openexchange.groupware.container.Contact)
+     */
+    public ContactUnificationState getAssociationBetween(Contact c1, Contact c2) throws OXException {
+        // TODO Auto-generated method stub
+        return null;
+    }
+
+    /* (non-Javadoc)
+     * @see com.openexchange.groupware.contact.ContactInterface#getContactByUUID(java.lang.String)
+     */
+    public Contact getContactByUUID(String uuid) throws OXException {
+        // TODO Auto-generated method stub
+        return null;
+    }
+
+    /* (non-Javadoc)
+     * @see com.openexchange.groupware.contact.ContactInterface#separateTwoContacts(com.openexchange.groupware.container.Contact, com.openexchange.groupware.container.Contact)
+     */
+    public void separateTwoContacts(Contact master, Contact slave) throws OXException {
+        // TODO Auto-generated method stub
+        
+    }
+
+	public SearchIterator<Contact> searchContacts(SearchTerm term, int orderBy,
+			String orderDir, int[] cols) throws OXException {
+		// TODO Auto-generated method stub
+		return null;
+	}
+
+	public <T> SearchIterator<Contact> getContactsByExtendedSearch(
+			SearchTerm<T> searchterm, int orderBy, Order order, String collation, int[] cols)
+			throws OXException {
+		// TODO Auto-generated method stub
+		return null;
+	}
+
 }
